from __future__ import unicode_literals

from django.db import models
from rest_framework import routers, serializers, viewsets
from warpauth.models import LdapUser

class ProductCategory(models.Model):
    name = models.CharField(max_length=100, unique=True)
    def __str__(self):
        return self.name
        
class Product(models.Model):
    name = models.CharField(max_length=100, null=True)
    price = models.FloatField()
    category = models.ForeignKey(ProductCategory, on_delete=models.CASCADE, null=True)
    count = models.IntegerField()

    def __str__(self):
        return self.name

class ProductSerializer(serializers.ModelSerializer):
    category = serializers.StringRelatedField()
    class Meta:
        model = Product
        fields = ['id', 'name', 'price', 'category', 'count']

        
class UserCredit(models.Model):
    uid = models.CharField(max_length=100,unique=True)
    card_id = models.CharField(max_length=10, null=True) # Unique only with django 1.11
    credit = models.FloatField()
    def __str__(self):
        return self.uid

class UserCreditSerializer(serializers.ModelSerializer):
    class Meta:
        model = UserCredit
        fields = ['uid', 'card_id', 'credit']
